@@ -6,9 +6,9 @@ use Class::Accessor::Lite;
 use Module::Load '';
 
 use Sisimai::Address;
-use Sisimai::RFC3463;
 use Sisimai::RFC5322;
-use Sisimai::RFC5321;
+use Sisimai::SMTP::Reply;
+use Sisimai::SMTP::Status;
 use Sisimai::String;
 use Sisimai::Reason;
 use Sisimai::Rhost;
@@ -100,7 +100,7 @@ sub new {
         'smtpcommand', 'feedbacktype', 'action', 'softbounce',
     );
     $thing->{ $_ } = $argvs->{ $_ } // '' for @v1;
-    $thing->{'replycode'} = Sisimai::RFC5321->getrc( $argvs->{'diagnosticcode'} );
+    $thing->{'replycode'}  = Sisimai::SMTP::Reply->find( $argvs->{'diagnosticcode'} );
     $thing->{'softbounce'} = 1 if $thing->{'replycode'} =~ m/\A4/;
 
     return bless( $thing, __PACKAGE__ );
@@ -108,16 +108,19 @@ sub new {
 
 sub make {
     # Another constructor of Sisimai::Data
-    # @param        [Hash] argvs Data and orders
-    # @option argvs [Sisimai::Message] data Object
-    # @return       [Array, Undef] List of Sisimai::Data or Undef if the argument
-    #                              (data) is not Sisimai::Message object
+    # @param        [Hash] argvs       Data and orders
+    # @option argvs [Sisimai::Message] Data Object
+    # @return       [Array, Undef]     List of Sisimai::Data or Undef if the 
+    #                                  argument is not Sisimai::Message object
     my $class = shift;
     my $argvs = { @_ };
 
     return undef unless exists $argvs->{'data'};
     return undef unless ref $argvs->{'data'} eq 'Sisimai::Message';
+    return undef unless $argvs->{'data'}->ds;
+    return undef unless $argvs->{'data'}->rfc822;
 
+    require Sisimai::SMTP;
     my $messageobj = $argvs->{'data'};
     my $rfc822data = $messageobj->rfc822;
     my $fieldorder = { 'recipient' => [], 'addresser' => [] };
@@ -125,14 +128,11 @@ sub make {
     my $rxcommands = qr/\A(?:EHLO|HELO|MAIL|RCPT|DATA|QUIT)\z/;
     my $givenorder = $argvs->{'order'} ? $argvs->{'order'} : {};
 
-    return undef unless $messageobj->ds;
-    return undef unless $messageobj->rfc822;
-
     # Decide the order of email headers: user specified or system default.
     if( ref $givenorder eq 'HASH' && scalar keys %$givenorder ) {
         # If the order of headers for searching is specified, use the order
         # for detecting an email address.
-        for my $e ( 'recipient', 'addresser' ) {
+        for my $e ( keys %$fieldorder ) {
             # The order should be "Array Reference".
             next unless $givenorder->{ $e };
             next unless ref $givenorder->{ $e } eq 'ARRAY';
@@ -141,7 +141,7 @@ sub make {
         }
     }
 
-    for my $e ( 'recipient', 'addresser' ) {
+    for my $e ( keys %$fieldorder ) {
         # If the order is empty, use default order.
         if( not scalar @{ $fieldorder->{ $e } } ) {
             # Load default order of each accessor.
@@ -193,8 +193,7 @@ sub make {
                 $p->{'recipient'} = $p->{'alias'};
                 $p->{'alias'} = $w;
             }
-
-        } # End of EMAIL_ADDRESS
+        }
         next unless $p->{'addresser'};
         next unless $p->{'recipient'};
 
@@ -226,7 +225,7 @@ sub make {
 
             if( defined $datestring ) {
                 # Get the value of timezone offset from $datestring
-                if( $datestring =~ m/\A(.+)\s+([-+]\d{4})\z/ ) {
+                if( $datestring =~ m/\A(.+)[ ]+([-+]\d{4})\z/ ) {
                     # Wed, 26 Feb 2014 06:05:48 -0500
                     $datestring = $1;
                     $zoneoffset = Sisimai::DateTime->tz2second($2);
@@ -244,19 +243,18 @@ sub make {
         next unless $p->{'timestamp'};
 
         OTHER_TEXT_HEADERS: {
-            # Remove square brackets and curly brackets from the host variable
-            map { $p->{ $_ } =~ y/[]()//d } ( 'rhost', 'lhost' ); 
+            for my $v ( 'rhost', 'lhost' ) {
+                $p->{ $v } =~ y/[]()//d;    # Remove square brackets and curly brackets from the host variable
+                $p->{ $v } =~ s/\A.+=//;    # Remove string before "="
 
-            # Remove string before "="
-            map { $p->{ $_ } =~ s/\A.+=// } ( 'rhost', 'lhost' );
-
-            for my $e ( 'rhost', 'lhost' ) {
                 # Check space character in each value
-                if( $p->{ $e } =~ m/ / ) {
+                if( $p->{ $v } =~ m/ / ) {
                     # Get the first element
-                    $p->{ $e } = (split( ' ', $p->{ $e }, 2 ))[0];
+                    $p->{ $v } = (split( ' ', $p->{ $v }, 2 ))[0];
                 }
             }
+
+            # Subject: header of the original message
             $p->{'subject'} = $rfc822data->{'subject'} // '';
 
             # The value of "List-Id" header
@@ -265,14 +263,14 @@ sub make {
                 # Get the value of List-Id header
                 if( $p->{'listid'} =~ m/\A.*([<].+[>]).*\z/ ) {
                     # List name <list-id@example.org>
-                    $p->{'listid'} =  $1 
+                    $p->{'listid'} = $1 
                 }
                 $p->{'listid'} =~ y/<>//d;
                 $p->{'listid'} =  '' if $p->{'listid'} =~ m/ /;
             }
 
             # The value of "Message-Id" header
-            $p->{'messageid'} =  $rfc822data->{'message-id'} // '';
+            $p->{'messageid'} = $rfc822data->{'message-id'} // '';
             if( length $p->{'messageid'} ) {
                 # Remove angle brackets
                 $p->{'messageid'} =  $1 if $p->{'messageid'} =~ m/\A([^ ]+)[ ].*/;
@@ -281,8 +279,8 @@ sub make {
 
             CHECK_DELIVERY_STATUS_VALUE: {
                 # Cleanup the value of "Diagnostic-Code:" header
-                $p->{'diagnosticcode'} =~ s/\s+$EndOfEmail//;
-                my $v = Sisimai::RFC3463->getdsn( $p->{'diagnosticcode'} );
+                $p->{'diagnosticcode'} =~ s/[ \t]+$EndOfEmail//;
+                my $v = Sisimai::SMTP::Status->find( $p->{'diagnosticcode'} );
                 if( $v =~ m/\A[45][.][1-9][.][1-9]\z/ ) {
                     # Use the DSN value in Diagnostic-Code:
                     $p->{'deliverystatus'} = $v;
@@ -312,10 +310,10 @@ sub make {
             # not have the value of "deliverystatus".
             unless( length $o->softbounce ) {
                 # The value is not set yet
-                for my $v ( 'deliverystatus',  'diagnosticcode' ) {
+                for my $v ( 'deliverystatus', 'diagnosticcode' ) {
                     # Set the value of softbounce
                     next unless length $p->{ $v };
-                    $o->softbounce( Sisimai::RFC3463->is_softbounce( $p->{ $v } ) );
+                    $o->softbounce( Sisimai::SMTP->is_softbounce( $p->{ $v } ) );
                     last if $o->softbounce > -1;
                 }
                 $o->softbounce(-1) unless length $o->softbounce;
@@ -326,13 +324,13 @@ sub make {
                 my $pdsv = undef; # Pseudo delivery status value
                 my $torp = undef; # Temporary or Permanent
 
-                $torp = $o->softbounce == 1 ? 't' : 'p';
-                $pdsv = Sisimai::RFC3463->status( $o->reason, $torp, 'i' );
+                $torp = $o->softbounce == 1 ? 1 : 0;
+                $pdsv = Sisimai::SMTP::Status->code( $o->reason, $torp );
 
                 if( length $pdsv ) {
                     # Set the value of "deliverystatus" and "softbounce".
                     $o->deliverystatus( $pdsv );
-                    $o->softbounce( Sisimai::RFC3463->is_softbounce( $pdsv ) ) if $o->softbounce < 0;
+                    $o->softbounce( Sisimai::SMTP->is_softbounce( $pdsv ) ) if $o->softbounce < 0;
                 }
             }
         } else {
@@ -377,16 +375,16 @@ sub damn {
 
 sub dump {
     # Data dumper
-    # @param    [String] argv   Data format: json, yaml
+    # @param    [String] type   Data format: json, yaml
     # @return   [String, Undef] Dumped data or Undef if the value of first
     #                           argument is neither "json" nor "yaml"
     my $self = shift;
-    my $argv = shift || 'json';
+    my $type = shift || 'json';
 
-    return undef unless $argv =~ m/\A(?:json|yaml)\z/;
+    return undef unless $type =~ m/\A(?:json|yaml)\z/;
 
     my $dumpeddata = '';
-    my $referclass = sprintf( "Sisimai::Data::%s", uc $argv );
+    my $referclass = sprintf( "Sisimai::Data::%s", uc $type );
 
     eval { Module::Load::load $referclass };
     $dumpeddata = $referclass->dump( $self );
@@ -689,8 +687,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
