@@ -99,9 +99,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-
     my $v = undef;
-    my $p = '';
 
     my $rxboundary = Sisimai::MIME->boundary( $mhead->{'content-type'}, 1 );
     my @rxmessages = ();
@@ -128,16 +126,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -148,7 +144,6 @@ sub scan {
                 next if length $e;
                 $rfc822next->{ $previousfn } = 1;
             }
-
         } else {
             # Before "message/rfc822"
             next unless $readcursor & $Indicators->{'deliverystatus'};
@@ -157,7 +152,7 @@ sub scan {
             $v = $dscontents->[ -1 ];
             if( $e =~ m/\A[<]([^ ]+[@][^ ]+)[>]\z/ ||
                 $e =~ m/\A[<]([^ ]+[@][^ ]+)[>]:?(.*)\z/ ||
-                $e =~ m/\A\s+Recipient: [<]([^ ]+[@][^ ]+)[>]/ ) {
+                $e =~ m/\A[ \t]+Recipient: [<]([^ ]+[@][^ ]+)[>]/ ) {
                 # The user(s) account is disabled.
                 #
                 # <***@ezweb.ne.jp>: 550 user unknown (in reply to RCPT TO command)
@@ -180,7 +175,6 @@ sub scan {
                     $v->{'recipient'} = $r;
                     $recipients++;
                 }
-
             } elsif( $e =~ m/\A[Ss]tatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
                 # Status: 5.1.1
                 # Status:5.2.0
@@ -201,7 +195,7 @@ sub scan {
 
             } else {
                 next if Sisimai::String->is_8bit( \$e );
-                if( $e =~ m/\A\s+[>]{3}\s+([A-Z]{4})/ ) {
+                if( $e =~ m/\A[ \t]+[>]{3}[ \t]+([A-Z]{4})/ ) {
                     #    >>> RCPT TO:<******@ezweb.ne.jp>
                     $v->{'command'} = $1;
 
@@ -217,19 +211,12 @@ sub scan {
                 }
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
-        $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
             # Get localhost and remote host name from Received header.
@@ -283,10 +270,11 @@ sub scan {
             }
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
-    } # end of for()
+        $e->{'agent'}  = __PACKAGE__->smtpagent;
+    }
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
 
@@ -332,8 +320,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
