@@ -14,7 +14,7 @@ my $Re1 = {
     'error'   => qr/The error that the other server returned was:/,
     'rfc822'  => qr{\A(?:
          -----[ ]Original[ ]message[ ]-----
-        |\s*-----[ ]Message[ ]header[ ]follows[ ]-----
+        |[ \t]*-----[ ]Message[ ]header[ ]follows[ ]-----
         )\z
     }x,
     'endof'   => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
@@ -195,14 +195,10 @@ sub scan {
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $softbounce = 0;     # (Integer) 1 = Soft bounce
     my $statecode0 = 0;     # (Integer) The value of (state *) in the error message
-
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
-        $e =~ s{=\d+\z}{};
-
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
             $readcursor |= $Indicators->{'deliverystatus'} if $e =~ $Re1->{'begin'};
@@ -223,16 +219,14 @@ sub scan {
                 next if $e =~ m/\ADKIM-Signature[:]/;
 
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -243,7 +237,6 @@ sub scan {
                 next if length $e;
                 $rfc822next->{ $previousfn } = 1;
             }
-
         } else {
             # Before "message/rfc822"
             next unless $readcursor & $Indicators->{'deliverystatus'};
@@ -266,7 +259,7 @@ sub scan {
             #
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A\s+([^ ]+[@][^ ]+)\z/ ) {
+            if( $e =~ m/\A[ \t]+([^ ]+[@][^ ]+)\z/ ) {
                 # kijitora@example.jp: 550 5.2.2 <kijitora@example>... Mailbox Full
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -286,38 +279,21 @@ sub scan {
                     # Technical details of temporary failure: 
                     $v->{'softbounce'} = $1 eq 'permanent' ? 0 : 1;
                 }
-
-                if( $e =~ m/=\z/ ) {
-                    # Google tried to deliver your message, but it was rejected by the recipient =
-                    # domain. We recommend contacting the other email provider for further inform=
-                    $e =~ s{=\z}{};
-                    $v->{'diagnosis'} .= $e;
-
-                } else {
-                    # No "=" character at the end of the line
-                    $v->{'diagnosis'} .= $e.' ';
-                }
+                $v->{'diagnosis'} .= $e.' ';
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
-        $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
         unless( $e->{'rhost'} ) {
             # Get the value of remote host
-            if( $e->{'diagnosis'} =~ m/\s+by\s+([^ ]+)[.]\s+\[(\d+[.]\d+[.]\d+[.]\d+)\][.]/ ) {
+            if( $e->{'diagnosis'} =~ m/[ \t]+by[ \t]+([^ ]+)[.][ \t]+\[(\d+[.]\d+[.]\d+[.]\d+)\][.]/ ) {
                 # Google tried to deliver your message, but it was rejected by # the server 
                 # for the recipient domain example.jp by mx.example.jp. [192.0.2.153].
                 my $x = $1;
@@ -355,21 +331,21 @@ sub scan {
             }
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
 
         if( $e->{'reason'} ) {
             # Set pseudo status code
             if( $e->{'status'} =~ m/\A[45][.][1-7][.][1-9]\z/ ) {
                 # Override bounce reason 
-                $e->{'reason'} = Sisimai::RFC3463->reason( $e->{'status'} );
+                $e->{'reason'} = Sisimai::SMTP::Status->name( $e->{'status'} );
 
             } 
         }
 
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
-
-    } # end of for()
+        $e->{'agent'}  = __PACKAGE__->smtpagent;
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -417,8 +393,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
