@@ -30,20 +30,20 @@ my $Re1 = {
 };
 
 my $ReFailure = {
+    # courier/module.esmtp/esmtpclient.c:526| hard_error(del, ctf, "No such domain.");
     'hostunknown' => qr{
-        # courier/module.esmtp/esmtpclient.c:526| hard_error(del, ctf, "No such domain.");
         \ANo[ ]such[ ]domain[.]\z
     }x,
+    # courier/module.esmtp/esmtpclient.c:531| hard_error(del, ctf,
+    # courier/module.esmtp/esmtpclient.c:532|  "This domain's DNS violates RFC 1035.");
     'systemerror' => qr{
-        # courier/module.esmtp/esmtpclient.c:531| hard_error(del, ctf,
-        # courier/module.esmtp/esmtpclient.c:532|  "This domain's DNS violates RFC 1035.");
         \AThis[ ]domain's[ ]DNS[ ]violates[ ]RFC[ ]1035[.]\z
     }x,
 };
 
 my $ReDelayed = {
+    # courier/module.esmtp/esmtpclient.c:535| soft_error(del, ctf, "DNS lookup failed.");
     'networkerror' => qr{
-        # courier/module.esmtp/esmtpclient.c:535| soft_error(del, ctf, "DNS lookup failed.");
         \ADNS[ ]lookup[ ]failed[.]\z
     },
 };
@@ -121,16 +121,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -198,7 +196,7 @@ sub scan {
                         $v->{'spec'} = uc $1;
                         $v->{'diagnosis'} = $2;
 
-                    } elsif( $p =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*/ && $e =~ m/\A[\s\t]+(.+)\z/ ) {
+                    } elsif( $p =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*/ && $e =~ m/\A[ \t]+(.+)\z/ ) {
                         # Continued line of the value of Diagnostic-Code header
                         $v->{'diagnosis'} .= ' '.$1;
                         $e = 'Diagnostic-Code: '.$e;
@@ -226,7 +224,6 @@ sub scan {
                 # ---------------------------------------------------------------------------
                 if( $e =~ m/\A[>]{3}[ ]+([A-Z]{4})[ ]?/ ) {
                     # >>> DATA
-                    next if $connheader->{'command'};
                     next if $commandtxt;
                     $commandtxt = $1;
 
@@ -254,12 +251,11 @@ sub scan {
     } continue {
         # Save the current line for the next loop
         $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
@@ -273,30 +269,27 @@ sub scan {
             $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
         }
 
-        SESSION: while(1) {
-            HARD_E: for my $r ( keys %$ReFailure ) {
-                # Verify each regular expression of session errors
-                next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
-                $e->{'reason'} = $r;
-                $e->{'softbounce'} = 0;
-                last(HARD_E);
-            }
-            last if $e->{'reason'};
+        HARD_E: for my $r ( keys %$ReFailure ) {
+            # Verify each regular expression of session errors
+            next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+            $e->{'reason'} = $r;
+            $e->{'softbounce'} = 0;
+            last;
+        }
 
+        unless( $e->{'reason'} ) {
             SOFT_E: for my $r ( keys %$ReDelayed ) {
                 # Verify each regular expression of session errors
                 next unless $e->{'diagnosis'} =~ $ReDelayed->{ $r };
                 $e->{'reason'} = $r;
                 $e->{'softbounce'} = 1;
-                last(SOFT_E);
+                last;
             }
-
-            last;
         }
 
         if( ! $e->{'status'} || $e->{'status'} =~ m/\d[.]0[.]0\z/ ) {
             # Get the status code from the respnse of remote MTA.
-            my $f = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+            my $f = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
             $e->{'status'} = $f if length $f;
         }
         $e->{'spec'}      = '' unless $e->{'spec'} =~ m/\A(?:SMTP|X-UNIX)\z/;
@@ -349,8 +342,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
