@@ -10,10 +10,23 @@ my $Re0 = {
 };
 my $Re1 = {
     'begin'  => qr/\A\z/,    # Blank line
+    'error'  => qr/Body of message generated response:/,
     'rfc822' => qr/\AOriginal message follows[.]\z/,
     'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
 
+my $ReSMTP = {
+    'conn' => qr{(?:
+         SMTP[ ]connection[ ]failed,
+        |Unexpected[ ]connection[ ]response[ ]from[ ]server:
+        )
+    },
+    'ehlo' => qr|Unexpected response to EHLO/HELO:|,
+    'mail' => qr|Server response to MAIL FROM:|,
+    'rcpt' => qr|Additional RCPT TO generated following response:|,
+    'data' => qr|DATA command generated response:|,
+};
+
 my $ReFailure = {
     'hostunknown' => qr{
         Unknown[ ]host
@@ -75,9 +88,7 @@ sub scan {
     my $previousfn = '';    # (String) Previous field name
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -101,16 +112,15 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
+                my $lhs = lc $1;
 
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -131,15 +141,15 @@ sub scan {
             # Original message follows.
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\A(.+)[:]\s*([^ ]+[@][^ ]+)\z/ ) {
+            if( $e =~ m/\A(.+)[ ](.+)[:][ \t]*([^ ]+[@][^ ]+)\z/ ) {
                 # Unknown user: kijitora@example.com
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
                     push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
                     $v = $dscontents->[ -1 ];
                 }
-                $v->{'diagnosis'} = $1;
-                $v->{'recipient'} = $2;
+                $v->{'diagnosis'} = $1.' '.$2;
+                $v->{'recipient'} = $3;
                 $recipients++;
 
             } elsif( $e =~ m/\Aundeliverable[ ]+to[ ]+(.+)\z/ ) {
@@ -151,21 +161,23 @@ sub scan {
                 }
                 $v->{'recipient'} = $1;
                 $recipients++;
+
+            } else {
+                # Other error message text
+                $v->{'alterrors'} .= ' '.$e if length $v->{'alterrors'};
+                if( $e =~ $Re1->{'error'} ) {
+                    # Body of message generated response:
+                    $v->{'alterrors'} = $e;
+                }
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
-        # Set default values if each value is empty.
         $e->{'agent'} = __PACKAGE__->smtpagent;
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -174,8 +186,22 @@ sub scan {
             $e->{'lhost'} ||= shift @{ Sisimai::RFC5322->received( $r->[0] ) };
             $e->{'rhost'} ||= pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
         }
+
+        if( exists $e->{'alterrors'} && length $e->{'alterrors'} ) {
+            # Copy alternative error message
+            $e->{'diagnosis'} = $e->{'alterrors'}.' '.$e->{'diagnosis'};
+            $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
+            delete $e->{'alterrors'};
+        }
         $e->{'diagnosis'} = Sisimai::String->sweep( $e->{'diagnosis'} );
 
+        COMMAND: for my $r ( keys %$ReSMTP ) {
+            # Detect SMTP command from the message
+            next unless $e->{'diagnosis'} =~ $ReSMTP->{ $r };
+            $e->{'command'} = uc $r;
+            last;
+        }
+
         SESSION: for my $r ( keys %$ReFailure ) {
             # Verify each regular expression of session errors
             next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
@@ -183,11 +209,10 @@ sub scan {
             last;
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
-
-    } # end of for()
+    }
 
     return { 'ds' => $dscontents, 'rfc822' => $rfc822part };
 }
@@ -236,8 +261,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
