@@ -115,9 +115,7 @@ sub scan {
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $localhost0 = '';    # (String) Local MTA
-
     my $v = undef;
-    my $p = '';
 
     for my $e ( @hasdivided ) {
         # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
@@ -141,16 +139,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*.+\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -177,11 +173,11 @@ sub scan {
             #    host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
             $v = $dscontents->[ -1 ];
 
-            if( $e =~ m/\s*This is a permanent error[.]\s*/ ) {
+            if( $e =~ m/[ \t]*This is a permanent error[.][ \t]*/ ) {
                 # deliver.c:6811|  "recipients. This is a permanent error. The following address(es) failed:\n");
                 $v->{'softbounce'} = 0;
 
-            } elsif( $e =~ m/\A\s*[<]([^ ]+[@][^ ]+)[>]:(.+)\z/ ) {
+            } elsif( $e =~ m/\A[ \t]*[<]([^ ]+[@][^ ]+)[>]:(.+)\z/ ) {
                 # A message that you have sent could not be delivered to one or more
                 # recipients.  This is a permanent error.  The following address failed:
                 #
@@ -201,22 +197,17 @@ sub scan {
                 $v->{'diagnosis'} .= $e.' ';
             }
         } # End of if: rfc822
-
-    } continue {
-        # Save the current line for the next loop
-        $p = $e;
-        $e = '';
     }
     return undef unless $recipients;
 
     if( scalar @{ $mhead->{'received'} } ) {
         # Get the name of local MTA
         # Received: from marutamachi.example.org (c192128.example.net [192.0.2.128])
-        $localhost0 = $1 if $mhead->{'received'}->[-1] =~ m/from\s([^ ]+) /;
+        $localhost0 = $1 if $mhead->{'received'}->[-1] =~ m/from[ \t]([^ ]+) /;
     }
 
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
@@ -228,7 +219,7 @@ sub scan {
 
         if( ! $e->{'rhost'} ) {
             # Get the remote host name
-            if( $e->{'diagnosis'} =~ m/host\s+([^\s]+)\s\[.+\]:\s/ ) {
+            if( $e->{'diagnosis'} =~ m/host[ \t]+([^ \t]+)[ \t]\[.+\]:[ \t]/ ) {
                 # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
                 $e->{'rhost'} = $1;
             }
@@ -236,55 +227,46 @@ sub scan {
             unless( $e->{'rhost'} ) {
                 if( scalar @{ $mhead->{'received'} } ) {
                     # Get localhost and remote host name from Received header.
-                    my $r = $mhead->{'received'};
-                    $e->{'rhost'} = pop @{ Sisimai::RFC5322->received( $r->[-1] ) };
+                    $e->{'rhost'} = pop @{ Sisimai::RFC5322->received( $mhead->{'received'}->[-1] ) };
                 }
             }
         }
 
         if( ! $e->{'command'} ) {
             # Get the SMTP command name for the session
-            COMMAND: while(1) {
-                # Get the SMTP command name for the session
-                SMTP: for my $r ( @$ReCommand ) {
-                    # Verify each regular expression of SMTP commands
-                    next unless $e->{'diagnosis'} =~ $r;
-                    $e->{'command'} = uc $1;
-                    last(COMMAND);
-                }
+            SMTP: for my $r ( @$ReCommand ) {
+                # Verify each regular expression of SMTP commands
+                next unless $e->{'diagnosis'} =~ $r;
+                $e->{'command'} = uc $1;
                 last;
             }
 
-            REASON: while(1) {
-                # Detect the reason of bounce
-                if( $e->{'command'} eq 'MAIL' ) {
-                    # MAIL | Connected to 192.0.2.135 but sender was rejected.
-                    $e->{'reason'} = 'rejected';
+            # Detect the reason of bounce
+            if( $e->{'command'} eq 'MAIL' ) {
+                # MAIL | Connected to 192.0.2.135 but sender was rejected.
+                $e->{'reason'} = 'rejected';
 
-                } elsif( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
-                    # HELO | Connected to 192.0.2.135 but my name was rejected.
-                    $e->{'reason'} = 'blocked';
+            } elsif( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
+                # HELO | Connected to 192.0.2.135 but my name was rejected.
+                $e->{'reason'} = 'blocked';
 
-                } else {
-                    # Verify each regular expression of session errors
-                    SESSION: for my $r ( keys %$ReFailure ) {
-                        # Check each regular expression
-                        next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
-                        $e->{'reason'} = $r;
-                        last;
-                    }
-                    last if $e->{'reason'};
+            } else {
+                # Verify each regular expression of session errors
+                SESSION: for my $r ( keys %$ReFailure ) {
+                    # Check each regular expression
+                    next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+                    $e->{'reason'} = $r;
+                    last;
+                }
 
-                    if( $e->{'diagnosis'} =~ $ReDelayed ) {
-                        # The reason "expired"
-                        $e->{'reason'} = 'expired';
-                    }
+                unless( $e->{'reason'} ) {
+                    # The reason "expired"
+                    $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $ReDelayed;
                 }
-                last;
             }
         }
 
-        $e->{'status'} = Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} = Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'spec'} = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
         $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
         $e->{'command'} ||= '';
@@ -336,8 +318,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
