@@ -11,9 +11,9 @@ my $roaccessors = [
 ];
 my $rwaccessors = [
     'path',     # [String] Path to each file 
-    'file',     # [String] File name of a mail in the Maildir/
+    'file',     # [String] Each file name of a mail in the Maildir/
     'inodes',   # [Array]  i-node List of files in the Maildir/
-    'handle',   # [IO::File] File handle
+    'handle',   # [IO::Dir] Directory handle
 ];
 Class::Accessor::Lite->mk_accessors( @$rwaccessors );
 Class::Accessor::Lite->mk_ro_accessors( @$roaccessors );
@@ -25,16 +25,16 @@ sub new {
     #                                          not a directory or does not exist
     my $class = shift;
     my $argvs = shift // return undef;
-    my $param = { 'inodes' => [] };
 
     return undef unless -d $argvs;
 
-    $param->{'dir'}    = $argvs;
-    $param->{'file'}   = undef;
-    $param->{'path'}   = undef;
-    $param->{'inodes'} = [];
-    $param->{'handle'} = IO::Dir->new( $argvs );
-
+    my $param = {
+        'dir'    => $argvs,
+        'file'   => undef,
+        'path'   => undef,
+        'inodes' => {},
+        'handle' => IO::Dir->new( $argvs ),
+    };
     return bless( $param, __PACKAGE__ );
 }
 
@@ -68,16 +68,13 @@ sub read {
             # Get inode number of the file
             $self->{'path'} = $emailindir;
             $emailinode = [ stat $emailindir ]->[1];
-            next if grep { $emailinode == $_ } @{ $self->{'inodes'} };
+            next if exists $self->{'inodes'}->{ $emailinode };
 
             $filehandle = IO::File->new( $emailindir, 'r' );
-            while( <$filehandle> ) {
-                # Concatenate the contents of each file
-                $readbuffer .= $_;
-            }
+            $readbuffer = do { local $/; <$filehandle> };
             $filehandle->close;
 
-            push @{ $self->{'inodes'} }, $emailinode;
+            $self->{'inodes'}->{ $emailinode } = 1;
             $self->{'file'} = $r;
 
             last;
@@ -162,8 +159,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
