@@ -39,7 +39,7 @@ my $Re1 = {
         |Return-Path:[ ]*[<].+[>]\z
         )\z
     }xi,
-    'error'  => qr/\A(?:[45]\d\d\s+|[<][^@]+[@][^@]+[>]:?\s+)/i,
+    'error'  => qr/\A(?:[45]\d\d[ \t]+|[<][^@]+[@][^@]+[>]:?[ \t]+)/i,
     'command'=> qr/[ ](RCPT|MAIL|DATA)[ ]+command\b/,
 };
 
@@ -113,17 +113,14 @@ sub scan {
             # After "message/rfc822"
             if( $e =~ m/\A([-0-9A-Za-z]+?)[:][ ]*(.+)\z/ ) {
                 # Get required headers only
-                my $lhs = $1;
-                my $rhs = $2;
-                my $whs = lc $lhs;
-
+                my $lhs = lc $1;
                 $previousfn = '';
-                next unless exists $RFC822Head->{ $whs };
+                next unless exists $RFC822Head->{ $lhs };
 
-                $previousfn  = lc $lhs;
+                $previousfn  = $lhs;
                 $rfc822part .= $e."\n";
 
-            } elsif( $e =~ m/\A[\s\t]+/ ) {
+            } elsif( $e =~ m/\A[ \t]+/ ) {
                 # Continued line from the previous line
                 next if $rfc822next->{ $previousfn };
                 $rfc822part .= $e."\n" if exists $LongFields->{ $previousfn };
@@ -174,7 +171,7 @@ sub scan {
 
             } elsif( $e =~ m/\A[Xx]-[Aa]ctual-[Rr]ecipient:[ ]*(?:RFC|rfc)822;[ ]*([^ ]+)\z/ ) {
                 # X-Actual-Recipient: 
-                if( $1 =~ m/\s+/ ) {
+                if( $1 =~ m/[ \t]+/ ) {
                     # X-Actual-Recipient: RFC822; |IFS=' ' && exec procmail -f- || exit 75 ...
 
                 } else {
@@ -271,7 +268,7 @@ sub scan {
                     # Diagnostic-Code: 554 ...
                     $v->{'diagnosis'} = $1;
 
-                } elsif( $p =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*/ && $e =~ m/\A[\s\t]+(.+)\z/ ) {
+                } elsif( $p =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*/ && $e =~ m/\A[ \t]+(.+)\z/ ) {
                     # Continued line of the value of Diagnostic-Code header
                     $v->{'diagnosis'} .= ' '.$1;
                     $e = 'Diagnostic-Code: '.$e;
@@ -330,127 +327,124 @@ sub scan {
                 }
             }
         } # End of if: rfc822
-
     } continue {
         # Save the current line for the next loop
         $p = $e;
-        $e = '';
     }
 
     BODY_PARSER_FOR_FALLBACK: {
         # Fallback, parse entire message body
-        unless( $recipients ) {
-            # Failed to get a recipient address at code above
-            $match ||= 1 if $mhead->{'from'}    =~ $Re0->{'from'};
-            $match ||= 1 if $mhead->{'subject'} =~ $Re0->{'subject'};
-            if( defined $mhead->{'return-path'} ) {
-                # Check the value of Return-Path of the message
-                $match ||= 1 if $mhead->{'return-path'} =~ $Re0->{'return-path'};
-            }
-            last unless $match;
+        last if $recipients;
 
-            my $RxSkip = qr{(?>
-                 \A[-]+=
-                |\A[\s\t]+\z
-                |\A\s*--
-                |\A\s+[=]\d+
-                |\AHi[ ][!]
-                |Content-(?:Description|Disposition|Transfer-Encoding|Type):[ ]
-                |(?:name|charset)=
-                |--\z
-                |:[ ]--------
-                )
-            }xi;
+        # Failed to get a recipient address at code above
+        $match ||= 1 if $mhead->{'from'}    =~ $Re0->{'from'};
+        $match ||= 1 if $mhead->{'subject'} =~ $Re0->{'subject'};
+        if( defined $mhead->{'return-path'} ) {
+            # Check the value of Return-Path of the message
+            $match ||= 1 if $mhead->{'return-path'} =~ $Re0->{'return-path'};
+        }
+        last unless $match;
 
-            my $RxEnd  = qr{(?:
-                 \AContent-Type:[ ]message/delivery-status
-                |\AHere[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]first[ ]part[ ]of[ ]the[ ]message
-                |\AThe[ ]non-delivered[ ]message[ ]is[ ]attached[ ]to[ ]this[ ]message.
-                |\AReceived:\s*
-                |\AReceived-From-MTA:\s*
-                |\AReporting-MTA:\s*
-                |\AReturn-Path:\s*
-                |\AA[ ]copy[ ]of[ ]the[ ]original[ ]message[ ]below[ ]this[ ]line:
-                |Attachment[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message
-                |Below[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]original[ ]message:
-                |Below[ ]this[ ]line[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message
-                |Message[ ]contains[ ].+[ ]file[ ]attachments
-                |Message[ ]text[ ]follows:[ ]
-                |Original[ ]message[ ]follows
-                |The[ ]attachment[ ]contains[ ]the[ ]original[ ]mail[ ]headers
-                |The[ ]first[ ]\d+[ ]lines[ ]
-                |Unsent[ ]Message[ ]below
-                |Your[ ]message[ ]reads[ ][(]in[ ]part[)]:
-                )
-            }xi;
+        my $re_skip = qr{(?>
+             \A[-]+=
+            |\A\s+\z
+            |\A\s*--
+            |\A\s+[=]\d+
+            |\AHi[ ][!]
+            |Content-(?:Description|Disposition|Transfer-Encoding|Type):[ ]
+            |(?:name|charset)=
+            |--\z
+            |:[ ]--------
+            )
+        }xi;
 
-            my $RxAddr = qr{(?:
-                 \A\s*
-                |\A["].+["]\s*
-                |\A\s*Recipient:\s*
-                |\A[ ]*Address:[ ]
-                |addressed[ ]to[ ]
-                |Could[ ]not[ ]be[ ]delivered[ ]to:[ ]
-                |delivered[ ]to[ ]+
-                |delivery[ ]failed:[ ]
-                |Did[ ]not[ ]reach[ ]the[ ]following[ ]recipient:[ ]
-                |Error-for:[ ]+
-                |Failed[ ]Recipient:[ ]
-                |Failed[ ]to[ ]deliver[ ]to[ ]
-                |generated[ ]from[ ]
-                |Intended[ ]recipient:[ ]
-                |Mailbox[ ]is[ ]full:[ ]
-                |RCPT[ ]To:
-                |SMTP[ ]Server[ ][<].+[>][ ]rejected[ ]recipient[ ]
-                |The[ ]following[ ]recipients[ ]returned[ ]permanent[ ]errors:[ ]
-                |The[ ]following[ ]message[ ]to[ ]
-                |Unknown[ ]User:[ ]
-                |undeliverable[ ]to[ ]
-                |Undeliverable[ ]Address:[ ]*
-                |You[ ]sent[ ]mail[ ]to[ ]
-                |Your[ ]message[ ]to[ ]
-                )
-                ['"]?[<]?([^\s\t\n\r@=]+[@][-.0-9A-Za-z]+[.][0-9A-Za-z]+)[>]?['"]?
-            }xi;
+        my $re_stop  = qr{(?:
+             \AContent-Type:[ ]message/delivery-status
+            |\AHere[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]first[ ]part[ ]of[ ]the[ ]message
+            |\AThe[ ]non-delivered[ ]message[ ]is[ ]attached[ ]to[ ]this[ ]message.
+            |\AReceived:[ \t]*
+            |\AReceived-From-MTA:[ \t]*
+            |\AReporting-MTA:[ \t]*
+            |\AReturn-Path:[ \t]*
+            |\AA[ ]copy[ ]of[ ]the[ ]original[ ]message[ ]below[ ]this[ ]line:
+            |Attachment[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message
+            |Below[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]original[ ]message:
+            |Below[ ]this[ ]line[ ]is[ ]a[ ]copy[ ]of[ ]the[ ]message
+            |Message[ ]contains[ ].+[ ]file[ ]attachments
+            |Message[ ]text[ ]follows:[ ]
+            |Original[ ]message[ ]follows
+            |The[ ]attachment[ ]contains[ ]the[ ]original[ ]mail[ ]headers
+            |The[ ]first[ ]\d+[ ]lines[ ]
+            |Unsent[ ]Message[ ]below
+            |Your[ ]message[ ]reads[ ][(]in[ ]part[)]:
+            )
+        }xi;
 
-            my $b = $dscontents->[ -1 ];
-            for my $e ( split( "\n", $$mbody ) ) {
-                # Get the recipient's email address and error messages.
-                last if $e =~ $Re1->{'endof'};
-                last if $e =~ $Re1->{'rfc822'};
-                last if $e =~ $RxEnd;
+        my $re_addr = qr{(?:
+             \A\s*
+            |\A["].+["]\s*
+            |\A[ \t]*Recipient:[ \t]*
+            |\A[ ]*Address:[ ]
+            |addressed[ ]to[ ]
+            |Could[ ]not[ ]be[ ]delivered[ ]to:[ ]
+            |delivered[ ]to[ ]+
+            |delivery[ ]failed:[ ]
+            |Did[ ]not[ ]reach[ ]the[ ]following[ ]recipient:[ ]
+            |Error-for:[ ]+
+            |Failed[ ]Recipient:[ ]
+            |Failed[ ]to[ ]deliver[ ]to[ ]
+            |generated[ ]from[ ]
+            |Intended[ ]recipient:[ ]
+            |Mailbox[ ]is[ ]full:[ ]
+            |RCPT[ ]To:
+            |SMTP[ ]Server[ ][<].+[>][ ]rejected[ ]recipient[ ]
+            |The[ ]following[ ]recipients[ ]returned[ ]permanent[ ]errors:[ ]
+            |The[ ]following[ ]message[ ]to[ ]
+            |Unknown[ ]User:[ ]
+            |undeliverable[ ]to[ ]
+            |Undeliverable[ ]Address:[ ]*
+            |You[ ]sent[ ]mail[ ]to[ ]
+            |Your[ ]message[ ]to[ ]
+            )
+            ['"]?[<]?([^\s\n\r@=]+[@][-.0-9A-Za-z]+[.][0-9A-Za-z]+)[>]?['"]?
+        }xi;
 
-                next unless length $e;
-                next if $e =~ $RxSkip;
-                next if $e =~ m/\A[*]/;
+        my $b = $dscontents->[ -1 ];
+        for my $e ( split( "\n", $$mbody ) ) {
+            # Get the recipient's email address and error messages.
+            last if $e =~ $Re1->{'endof'};
+            last if $e =~ $Re1->{'rfc822'};
+            last if $e =~ $re_stop;
 
-                if( $e =~ $RxAddr ) {
-                    # May be an email address
-                    my $x = $b->{'recipient'} || '';
-                    my $y = Sisimai::Address->s3s4( $1 );
+            next unless length $e;
+            next if $e =~ $re_skip;
+            next if $e =~ m/\A[*]/;
 
-                    if( length $x && $x ne $y ) {
-                        # There are multiple recipient addresses in the message body.
-                        push @$dscontents, Sisimai::MTA->DELIVERYSTATUS;
-                        $b = $dscontents->[ -1 ];
-                    }
-                    $b->{'recipient'} = $y;
-                    $b->{'agent'} = __PACKAGE__->smtpagent.'::Fallback';
-                    $recipients++;
-
-                } elsif( $e =~ m/[(]expanded[ ]from:[ ]([^@]+[@][^@]+)[)]/ ) {
-                    # (expanded from: neko@example.jp)
-                    $b->{'alias'} = Sisimai::Address->s3s4( $1 );
+            if( $e =~ $re_addr ) {
+                # May be an email address
+                my $x = $b->{'recipient'} || '';
+                my $y = Sisimai::Address->s3s4( $1 );
 
+                if( length $x && $x ne $y ) {
+                    # There are multiple recipient addresses in the message body.
+                    push @$dscontents, Sisimai::MTA->DELIVERYSTATUS;
+                    $b = $dscontents->[ -1 ];
                 }
-                $b->{'diagnosis'} .= ' '.$e;
+                $b->{'recipient'} = $y;
+                $b->{'agent'} = __PACKAGE__->smtpagent.'::Fallback';
+                $recipients++;
+
+            } elsif( $e =~ m/[(]expanded[ ]from:[ ]([^@]+[@][^@]+)[)]/ ) {
+                # (expanded from: neko@example.jp)
+                $b->{'alias'} = Sisimai::Address->s3s4( $1 );
             }
+            $b->{'diagnosis'} .= ' '.$e;
         }
     }
 
     return undef unless $recipients;
     require Sisimai::String;
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
@@ -478,7 +472,7 @@ sub scan {
             # Set the value of smtpagent
             $e->{'agent'} = __PACKAGE__->smtpagent;
         }
-        $e->{'status'} ||= Sisimai::RFC3463->getdsn( $e->{'diagnosis'} );
+        $e->{'status'} ||= Sisimai::SMTP::Status->find( $e->{'diagnosis'} );
         $e->{'command'}  = $1 if $e->{'diagnosis'} =~ $Re1->{'command'};
 
         if( scalar @{ $mhead->{'received'} } ) {
@@ -536,8 +530,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
