@@ -61,7 +61,7 @@ sub get {
         }
     }
 
-    if( not $reasontext ) {
+    if( not $reasontext || $reasontext eq 'undefined' ) {
         # Bounce reason is not detected yet.
         while( 1 ) {
             # Check with other patterns
@@ -78,8 +78,11 @@ sub get {
             last;
         }
 
-        $reasontext ||= 'expired' if $argvs->action eq 'delayed';
-        $reasontext ||= 'onhold'  if length $argvs->diagnosticcode;
+        if( $reasontext eq 'undefined' || $reasontext eq '' ) {
+            # Action: delayed => "expired"
+            $reasontext ||= 'expired' if $argvs->action eq 'delayed';
+            $reasontext ||= 'onhold'  if length $argvs->diagnosticcode;
+        }
         $reasontext ||= 'undefined';
     }
 
@@ -108,11 +111,8 @@ sub anotherone {
         'SystemFull', 'NotAccept', 'MailerError',
     ];
 
-    require Sisimai::RFC3463;
-    for my $e ( 'temporary', 'permanent' ) {
-        $reasontext = Sisimai::RFC3463->reason( $statuscode, $e );
-        last if $reasontext;
-    }
+    require Sisimai::SMTP::Status;
+    $reasontext = Sisimai::SMTP::Status->name( $statuscode );
 
     if( $reasontext eq '' || $reasontext eq 'userunknown' ||
         grep { $reasontext eq $_ } @$RetryReasons ) {
@@ -145,25 +145,31 @@ sub anotherone {
         }
 
         if( not $reasontext ) {
-            # Check the value of SMTP command
-            if( $commandtxt =~ m/\A(?:EHLO|HELO)\z/ ) {
-                # Rejected at connection or after EHLO|HELO
-                $reasontext = 'blocked';
+            # Check the value of Action: field, first
+            if( $argvs->action =~ /\A(?:delayed|expired)/ ) {
+                # Action: delayed, expired
+                $reasontext = 'expired';
+
+            } else {
+                # Check the value of SMTP command
+                if( $commandtxt =~ m/\A(?:EHLO|HELO)\z/ ) {
+                    # Rejected at connection or after EHLO|HELO
+                    $reasontext = 'blocked';
+                }
             }
         }
-
     }
     return $reasontext;
 }
 
 sub match {
     # Detect the bounce reason from given text
-    # @param    [String] argvs  Error message
+    # @param    [String] argv1  Error message
     # @return   [String]        Bounce reason
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
 
     my $reasontext = '';
     my $statuscode = '';
@@ -176,8 +182,8 @@ sub match {
         'SystemFull', 'NotAccept', 'MailerError', 'NoRelaying', 'OnHold',
     ];
 
-    $statuscode = Sisimai::RFC3463->getdsn( $argvs ) || '';
-    $typestring = uc( $1 ) if $argvs =~ m/\A(SMTP|X-.+);/i;
+    $statuscode = Sisimai::SMTP::Status->find( $argv1 );
+    $typestring = uc( $1 ) if $argv1 =~ m/\A(SMTP|X-.+);/i;
 
     # Diagnostic-Code: SMTP; ... or empty value
     for my $e ( @$classorder ) {
@@ -186,7 +192,7 @@ sub match {
         my $p = 'Sisimai::Reason::'.$e;
         Module::Load::load( $p );
 
-        next unless $p->match( $argvs );
+        next unless $p->match( $argv1 );
         $reasontext = $p->text;
         last;
     }
@@ -196,13 +202,12 @@ sub match {
         if( $typestring eq 'X-UNIX' ) {
             # X-Unix; ...
             $reasontext = 'mailererror';
-        }
-        else {
+
+        } else {
             # Detect the bounce reason from "Status:" code
-            $reasontext = Sisimai::RFC3463->reason( $statuscode ) || 'undefined';
+            $reasontext = Sisimai::SMTP::Status->name( $statuscode ) || 'undefined';
         }
     }
-
     return $reasontext;
 }
 
@@ -503,8 +508,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
