@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'expired' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?:
          connection[ ]timed[ ]out
         |could[ ]not[ ]find[ ]a[ ]gateway[ ]for
@@ -27,11 +27,18 @@ sub match {
         )
     }ix;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
-sub true { return undef };
+sub true {
+    # Delivery expired due to connection failure or network error
+    # @param    [Sisimai::Data] argvs   Object to be detected the reason
+    # @return   [Integer]               1: is expired
+    #                                   0: is not expired
+    # @see      http://www.ietf.org/rfc/rfc2822.txt
+    return undef;
+}
 
 1;
 __END__
@@ -49,10 +56,10 @@ Sisimai::Reason::Expired - Bounce reason is C<expired> or not.
 
 =head1 DESCRIPTION
 
-Sisimai::Reason::Expired checks the bounce reason is C<expired> or not.  This 
+Sisimai::Reason::Expired checks the bounce reason is C<expired> or not. This
 class is called only Sisimai::Reason class.
 
-This is the error that delivery time has expired due to connection failure or 
+This is the error that delivery time has expired due to connection failure or
 network error and the message you sent has been in the queue for long time.
 
 =head1 CLASS METHODS
@@ -80,8 +87,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
