@@ -4,7 +4,15 @@ use strict;
 use warnings;
 
 sub text  { 'onhold' }
-sub match { return 0 }
+sub match { 
+    # Try to match that the given text and regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
+    # @return   [Integer]       0: Did not match
+    #                           1: Matched
+    # @since v4.0.0
+    return 0;
+}
+
 sub true  {
     # On hold, Could not decide the bounce reason...
     # @param    [Sisimai::Data] argvs   Object to be detected the reason
@@ -22,8 +30,9 @@ sub true  {
     return undef unless length $statuscode;
     return 1 if $argvs->reason eq $reasontext;
 
-    require Sisimai::RFC3463;
-    return 1 if Sisimai::RFC3463->reason( $statuscode ) eq $reasontext;
+    require Sisimai::SMTP::Status;
+    return 1 if Sisimai::SMTP::Status->name( $statuscode ) eq $reasontext;
+    return 0
 }
 
 1;
@@ -73,8 +82,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
