@@ -6,12 +6,12 @@ use warnings;
 sub text  { 'userunknown' }
 sub match {
     # Try to match that the given text and regular expressions
-    # @param    [String] argvs  String to be matched with regular expressions
+    # @param    [String] argv1  String to be matched with regular expressions
     # @return   [Integer]       0: Did not match
     #                           1: Matched
     # @since v4.0.0
     my $class = shift;
-    my $argvs = shift // return undef;
+    my $argv1 = shift // return undef;
     my $regex = qr{(?>
          .+[ ]user[ ]unknown
         |[#]5[.]1[.]1[ ]bad[ ]address
@@ -19,7 +19,7 @@ sub match {
         |address[ ]does[ ]not[ ]exist
         |address[ ]unknown
         |archived[ ]recipient
-        |BAD[-_\s]RECIPIENT
+        |BAD[-_ \t]RECIPIENT
         |destination[ ]addresses[ ]were[ ]unknown
         |destination[ ]server[ ]rejected[ ]recipients
         |email[ ]address[ ]does[ ]not[ ]exist
@@ -80,9 +80,9 @@ sub match {
             |no[ ]mailbox[ ]here[ ]by[ ]that[ ]name
             )
         |the[ ](?:
-              following[ ]recipients[ ]was[ ]undeliverable
-             |user[']s[ ]email[ ]name[ ]is[ ]not[ ]found
-             )
+             following[ ]recipients[ ]was[ ]undeliverable
+            |user[']s[ ]email[ ]name[ ]is[ ]not[ ]found
+            )
         |this[ ](?:
              address[ ]no[ ]longer[ ]accepts[ ]mail
             |email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
@@ -109,7 +109,7 @@ sub match {
         )
     }xi;
 
-    return 1 if $argvs =~ $regex;
+    return 1 if $argv1 =~ $regex;
     return 0;
 }
 
@@ -126,17 +126,15 @@ sub true {
     return undef unless ref $argvs eq 'Sisimai::Data';
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
-    require Sisimai::RFC3463;
+    require Sisimai::SMTP::Status;
     my $prematches = [ 'NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved' ];
     my $matchother = 0;
     my $statuscode = $argvs->deliverystatus // '';
+    my $diagnostic = $argvs->diagnosticcode // '';
+    my $tempreason = Sisimai::SMTP::Status->name( $statuscode );
     my $reasontext = __PACKAGE__->text;
-    my $tempreason = '';
-    my $diagnostic = '';
     my $v = 0;
 
-    $tempreason = Sisimai::RFC3463->reason( $statuscode ) if $statuscode;
-    $diagnostic = $argvs->diagnosticcode // '';
     return 0 if $tempreason eq 'suspend';
 
     if( $tempreason eq $reasontext ) {
@@ -228,8 +226,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2015 azumakuniyuki E<lt>perl.org@azumakuniyuki.orgE<gt>,
-All Rights Reserved.
+Copyright (C) 2014-2015 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
